@@ -10,6 +10,7 @@ import json
 from base64 import b64decode
 from collections.abc import Iterable, Mapping
 from datetime import date, datetime, time as dt_time
+from html import escape
 from typing import (
     TYPE_CHECKING, Any, ClassVar, Type,
 )
@@ -34,9 +35,7 @@ from ..models import (
     DatetimePicker as _bkDatetimePicker, TextAreaInput as _bkTextAreaInput,
     TextInput as _BkTextInput, TimePicker as _BkTimePicker,
 )
-from ..util import (
-    escape, lazy_load, param_reprs, try_datetime64_to_datetime,
-)
+from ..util import lazy_load, param_reprs, try_datetime64_to_datetime
 from .base import CompositeWidget, Widget
 
 if TYPE_CHECKING:
@@ -993,6 +992,9 @@ class _SpinnerBase(_NumericInputBase):
         Defines the multiplication factor applied to step when the page up
         and page down keys are pressed.""")
 
+    placeholder = param.String(default='', doc="""
+        Placeholder when the value is empty.""")
+
     wheel_wait = param.Integer(default=100, doc="""
         Defines the debounce time in ms before updating `value_throttled` when
         the mouse wheel is used to change the input.""")
